#include "configdialog.h"
#include "ui_configdialog.h"

ConfigDialog::ConfigDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::ConfigDialog)
{
    ui->setupUi(this);
    setWindowTitle("Effing Configuration");
}

ConfigDialog::~ConfigDialog()
{
    delete ui;
}

bool ConfigDialog::is_tagline_G()
{
    return ui->radio_G_rated->isChecked();
}

bool ConfigDialog::is_tagline_non_G()
{
     return ui->radio_not_G_rated->isChecked();
}

bool ConfigDialog::is_target_full()
{
    return ui->radio_full_facebook->isChecked();
}

bool ConfigDialog::is_target_touch()
{
    return ui->radio_touch->isChecked();
}

void ConfigDialog::set_tagline_G(bool value)
{
    if (value) ui->radio_G_rated->setChecked(true);
    else ui->radio_not_G_rated->setChecked(true);
}

void ConfigDialog::set_tagline_non_G(bool value)
{
    if (value) ui->radio_not_G_rated->setChecked(true);
    else ui->radio_G_rated->setChecked(true);
}

void ConfigDialog::set_target_full(bool value)
{
    if (value) ui->radio_full_facebook->setChecked(true);
    else ui->radio_touch->setChecked(true);;
}

void ConfigDialog::set_target_touch(bool value)
{
    if (value) ui->radio_touch->setChecked(true);
    else ui->radio_full_facebook->setChecked(true);;
}

void ConfigDialog::on_button_unauthorize_clicked()
{
    emit do_unauthorize();
}
